======================
Global Logger
======================


.. image:: https://img.shields.io/pypi/v/global_logger.svg
        :target: https://pypi.python.org/pypi/global_logger

.. image:: https://readthedocs.org/projects/global-logger/badge/?version=latest
        :target: https://global-logger.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://github.com/ALERTua/global_logger/workflows/Python%20Package/badge.svg?branch=master
        :target: https://github.com/ALERTua/global_logger/actions?query=workflow%3A%22Python+Package%22




Global Logger

Based on Python built-in logger, expands it and provides global logger to your system.

* Free software: MIT license
* Documentation: https://global-logger.readthedocs.io.


Features
--------

* Python 2 and 3 compatible
* Warning! Python2 files have to have 'from __future__ import print_function, unicode_literals' at the top
